@@ -8,7 +8,7 @@
 #' @export
 manage_cases <- function(package = ".", filter = NULL) {
   cases <- collect_cases(package, filter = filter)
-  cases <- filter_cases(cases, c("case_new", "case_mismatch", "case_orphaned"))
+  cases <- filter_cases(cases, c("new_case", "mismatch_case", "orphaned_case"))
 
   vdiffrApp <- shiny::shinyApp(
     ui = vdiffrUi(cases),
@@ -27,7 +27,7 @@ manage_cases <- function(package = ".", filter = NULL) {
 vdiffrAddin <- function() {
   pkg_path <- rstudioapi::getActiveProject() %||% "."
   cases <- collect_cases(pkg_path)
-  cases <- filter_cases(cases, c("case_new", "case_mismatch", "case_orphaned"))
+  cases <- filter_cases(cases, c("new_case", "mismatch_case", "orphaned_case"))
 
   vdiffrApp <- shiny::shinyApp(
     ui = vdiffrUi(cases),
